@@ -3,8 +3,11 @@
 #' @description [readd()] returns an object from the cache,
 #' and [loadd()] loads one or more objects from the cache
 #' into your environment or session. These objects are usually
-#' targets built by [make()].
-#' @details There are two uses for the
+#' targets built by [make()]. If `target` is dynamic,
+#' [readd()] and [loadd()] retrieve a list of sub-target values.
+#' You can restrict which sub-targets to include using the `subtargets`
+#' argument.
+#' @details There are three uses for the
 #' [loadd()] and [readd()] functions:
 #' 1. Exploring the results outside the `drake`/`make()` pipeline.
 #'   When you call [make()] to run your project,
@@ -57,6 +60,12 @@
 #' @param show_source Logical, option to show the command
 #'   that produced the target or indicate that the object
 #'   was imported (using [show_source()]).
+#' @param subtargets A numeric vector of indices.
+#'   If `target` is dynamic, [loadd()] and [readd()] retrieve
+#'   a list of sub-targets. You can restrict which sub-targets
+#'   to retrieve with the `subtargets` argument. For example,
+#'   `readd(x, subtargets = seq_len(3))` only retrieves the
+#'   first 3 sub-targets of dynamic target `x`.
 #' @examples
 #' \dontrun{
 #' isolate_example("Quarantine side effects.", {
@@ -79,7 +88,8 @@ readd <- function(
   cache = drake::drake_cache(path = path),
   namespace = NULL,
   verbose = 1L,
-  show_source = FALSE
+  show_source = FALSE,
+  subtargets = NULL
 ) {
   deprecate_search(search)
   # if the cache is null after trying drake_cache:
@@ -100,11 +110,12 @@ readd <- function(
       character_only = TRUE
     )
   }
-  cache$get(
+  value <- cache$get(
     standardize_key(target),
     namespace = namespace,
     use_cache = FALSE
   )
+  get_subtargets(value, cache, subtargets)
 }
 
 #' @title Load one or more targets or imports from the drake cache.
@@ -213,7 +224,8 @@ loadd <- function(
   replace = TRUE,
   show_source = FALSE,
   tidyselect = !deps,
-  config = NULL
+  config = NULL,
+  subtargets = NULL
 ) {
   deprecate_search(search)
   deprecate_arg(graph, "graph") # 2019-01-04 # nolint
@@ -254,13 +266,70 @@ loadd <- function(
   targets <- loadd_handle_replace(targets, envir, replace)
   loadd_show_source(targets, cache = cache, show_source = show_source)
   lightly_parallelize(
-    X = targets, FUN = load_target, cache = cache,
-    namespace = namespace, envir = envir,
-    verbose = verbose, lazy = lazy
+    X = targets,
+    FUN = load_target,
+    cache = cache,
+    namespace = namespace,
+    envir = envir,
+    verbose = verbose,
+    lazy = lazy
+  )
+  lapply(
+    targets,
+    load_subtargets,
+    cache = cache,
+    envir = envir,
+    subtargets = subtargets
   )
   invisible()
 }
 
+load_subtargets <- function(target, cache, envir, subtargets) {
+  hashes <- get(target, envir = envir, inherits = FALSE)
+  load_targets_impl(hashes, target, cache, envir, subtargets)
+}
+
+load_targets_impl <- function(hashes, target, cache, envir, subtargets) {
+  UseMethod("load_targets_impl")
+}
+
+load_targets_impl.drake_dynamic <- function( # nolint
+  hashes,
+  target,
+  cache,
+  envir,
+  subtargets
+) {
+  value <- get_subtargets(hashes, cache, subtargets)
+  rm(list = target, envir = envir, inherits = FALSE)
+  assign(target, value, envir = envir, inherits = FALSE)
+}
+
+load_targets_impl.default <- function(
+  hashes,
+  target,
+  cache,
+  envir,
+  subtargets
+) {
+  NULL
+}
+
+get_subtargets <- function(hashes, cache, subtargets) {
+  UseMethod("get_subtargets")
+}
+
+get_subtargets.drake_dynamic <- function(hashes, cache, subtargets) {
+  if (!is.null(subtargets)) {
+    hashes <- hashes[subtargets]
+  }
+  lapply(hashes, cache$get_value, use_cache = FALSE)
+}
+
+get_subtargets.default <- function(hashes, cache, subtargets) {
+  hashes
+}
+
 loadd_handle_empty_targets <- function(targets, cache, ...) {
   if (!length(targets) && !length(list(...))) {
     targets <- cache$list()
@@ -333,99 +402,6 @@ parse_lazy_arg <- function(lazy) {
   }
 }
 
-load_target <- function(target, cache, namespace, envir, verbose, lazy) {
-  switch(
-    lazy,
-    eager = eager_load_target(
-      target = target,
-      cache = cache,
-      namespace = namespace,
-      envir = envir,
-      verbose = verbose
-    ),
-    promise = promise_load_target(
-      target = target,
-      cache = cache,
-      namespace = namespace,
-      envir = envir,
-      verbose = verbose
-    ),
-    bind = bind_load_target(
-      target = target,
-      cache = cache,
-      namespace = namespace,
-      envir = envir,
-      verbose = verbose
-    )
-  )
-}
-
-#' @title Load a target right away (internal function)
-#' \lifecycle{stable}
-#' @description This function is only exported
-#' to make active bindings work safely.
-#' It is not actually a user-side function.
-#' @keywords internal
-#' @export
-#' @inheritParams loadd
-eager_load_target <- function(target, cache, namespace, envir, verbose) {
-  value <- cache$get(
-    key = target,
-    namespace = namespace,
-    use_cache = FALSE
-  )
-  assign(x = target, value = value, envir = envir)
-  local <- environment()
-  rm(value, envir = local)
-  invisible()
-}
-
-promise_load_target <- function(target, cache, namespace, envir, verbose) {
-  eval_env <- environment()
-  delayedAssign(
-    x = target,
-    value = cache$get(
-      key = target,
-      namespace = namespace,
-      use_cache = FALSE
-    ),
-    eval.env = eval_env,
-    assign.env = envir
-  )
-}
-
-bind_load_target <- function(target, cache, namespace, envir, verbose) {
-  assert_pkg("bindr")
-  # Allow active bindings to overwrite existing variables.
-  if (exists(x = target, envir = envir, inherits = FALSE)) {
-    message(
-      "Replacing already-loaded variable ", target,
-      " with an active binding."
-    )
-    remove(list = target, envir = envir)
-  }
-  bindr::populate_env(
-    env = envir,
-    names = as.character(target),
-    fun = function(key, cache, namespace) {
-      if (!length(namespace)) {
-        # Now impractical to cover because loadd() checks the namespace,
-        # but good to have around anyway.
-        namespace <- cache$default_namespace # nocov
-      }
-      cache$get(
-        key = as.character(key),
-        namespace = as.character(namespace),
-        use_cache = FALSE
-      )
-    },
-    cache = cache,
-    namespace = namespace
-  )
-}
-
-
-
 #' @title Show how a target/import was produced.
 #' \lifecycle{stable}
 #' @description Show the command that produced a target
@@ -838,7 +814,7 @@ new_cache <- function(
     warning(
       "The 'type' argument of new_cache() is deprecated. ",
       "Please see the storage guide in the manual for the new cache API:",
-      "https://ropenscilabs.github.io/drake-manual/store.html"
+      "https://books.ropensci.org/drake/storage.html"
     )
   }
   deprecate_hash_algo_args(short_hash_algo, long_hash_algo)
@@ -1170,7 +1146,7 @@ diagnose <- function(
   }
   target <- standardize_key(target)
   if (!cache$exists(key = target, namespace = "meta")) {
-    stop("No diagnostic information for target ", target, ".")
+    stop("No metadata for target ", target, ".")
   }
   cache$get(
     key = target,
