@@ -1463,7 +1463,7 @@ target_namespaces <- function(
 #' @title Specialized wildcard for analyses
 #' \lifecycle{deprecated}
 #' @description Use [drake_plan()] instead.
-#'   See <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   See <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for details.
 #' @details 2019-01-13
 #' @export
@@ -1486,7 +1486,7 @@ plan_analyses <- function(plan, datasets, sep = "_") {
     msg = paste(
       "plan_analyses() in drake is deprecated.",
       "Use drake_plan() with transformations instead. See",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans",
+      "https://books.ropensci.org/drake/plans.html#large-plans",
       "for details."
     )
   )
@@ -1501,7 +1501,7 @@ plan_analyses <- function(plan, datasets, sep = "_") {
 #' @title Specialized wildcard for summaries
 #' \lifecycle{deprecated}
 #' @description Use [drake_plan()] with transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for details.
 #' @details 2019-01-13
 #' @export
@@ -1534,7 +1534,7 @@ plan_summaries <- function(
     msg = paste(
       "plan_summaries() in drake is deprecated.",
       "Use drake_plan() with transformations instead:",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   plan <- with_analyses_only(plan)
@@ -1794,7 +1794,7 @@ drake_cache_log_file <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #'
 #' @details The commands in workflow plan data frames can have
@@ -1870,7 +1870,7 @@ evaluate_plan <- function(
     package = "drake",
     msg = paste(
       "evaluate_plan() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   plan <- deparse_lang_cols(plan)
@@ -2021,7 +2021,7 @@ check_wildcard_rules <- function(rules) {
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #'
 #' @details Duplicates the rows of a workflow plan data frame.
@@ -2048,7 +2048,7 @@ expand_plan <- function(
     package = "drake",
     msg = paste(
       "expand_plan() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   if (!length(values)) {
@@ -2073,7 +2073,7 @@ expand_plan <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #' @details `map_plan()` is like `base::Map()`:
 #'   it takes a function name and a grid of arguments, and
@@ -2114,7 +2114,7 @@ map_plan <- function(
     package = "drake",
     msg = paste(
       "map_plan() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   args <- weak_as_tibble(args)
@@ -2150,7 +2150,7 @@ map_plan <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #' @details Creates a new workflow plan to aggregate
 #'   existing targets in the supplied plan.
@@ -2178,7 +2178,7 @@ gather_plan <- function(
     package = "drake",
     msg = paste(
       "gather_plan() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   command <- paste(plan$target, "=", plan$target)
@@ -2197,7 +2197,7 @@ gather_plan <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #' @details Perform several calls to `gather_plan()`
 #'   based on groupings from columns in the plan,
@@ -2236,7 +2236,7 @@ gather_by <- function(
     package = "drake",
     msg = paste(
       "gather_by() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   gathered <- plan
@@ -2273,7 +2273,7 @@ gather_by <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #' @details Creates a new workflow plan data frame with the
 #'   commands to do a reduction (i.e. to repeatedly apply a binary
@@ -2313,7 +2313,7 @@ reduce_plan <- function(
     package = "drake",
     msg = paste(
       "reduce_plan() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   if (pairwise) {
@@ -2347,7 +2347,7 @@ reduce_plan <- function(
 #' \lifecycle{deprecated}
 #' @description Deprecated on 2019-05-16. Use [drake_plan()]
 #'   transformations instead. See
-#'   <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans>
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>
 #'   for the details.
 #' @details Perform several calls to `reduce_plan()`
 #'   based on groupings from columns in the plan,
@@ -2389,7 +2389,7 @@ reduce_by <- function(
     package = "drake",
     msg = paste(
       "reduce_by() is deprecated. For the new interface, visit",
-      "https://ropenscilabs.github.io/drake-manual/plans.html#large-plans"
+      "https://books.ropensci.org/drake/plans.html#large-plans"
     )
   )
   reduced <- plan
