@@ -87,7 +87,8 @@
 #'
 #' @param hover Logical, whether to show text (file contents,
 #'   commands, etc.) when you hover your cursor over a node.
-#'
+#' @param on_select_col Optional string corresponding to the column name
+#'   in the plan that should provide data for the `on_select` event.
 #' @examples
 #' \dontrun{
 #' isolate_example("Quarantine side effects.", {
@@ -133,7 +134,8 @@ drake_graph_info <- function(
   group = NULL,
   clusters = NULL,
   show_output_files = TRUE,
-  hover = FALSE
+  hover = FALSE,
+  on_select_col = NULL
 ) {
   assert_pkg("visNetwork")
   assert_config_not_plan(config)
@@ -150,6 +152,7 @@ drake_graph_info <- function(
   config$group <- as.character(group)
   config$clusters <- as.character(clusters)
   config$hover <- hover
+  config$on_select_col <- on_select_col
   config$file_out <- lapply(all_targets(config), function(target) {
     config$layout[[target]]$deps_build$file_out
   })
@@ -195,6 +198,10 @@ drake_graph_info <- function(
   if (nrow(config$edges)) {
     config$edges$arrows <- "to"
   }
+  if (!is.null(config$on_select_col)) {
+    config$nodes$on_select_col <- get_select_col(config)
+  }
+
   if (length(config$group)) {
     config <- cluster_nodes(config)
   }
@@ -213,6 +220,13 @@ drake_graph_info <- function(
 get_raw_node_category_data <- function(config) {
   all_labels <- V(config$graph)$name
   config$targets <- all_targets(config)
+  is_dynamic <- vapply(
+    config$targets,
+    is_dynamic,
+    FUN.VALUE = logical(1),
+    config = config
+  )
+  config$dynamic <- config$targets[is_dynamic]
   config$outdated <- resolve_graph_outdated(config = config)
   config$running <- running(cache = config$cache)
   config$failed <- failed(cache = config$cache)
@@ -292,6 +306,10 @@ resolve_build_times <- function(build_times) {
   build_times
 }
 
+get_select_col <- function(config) {
+  get_cluster_grouping(config, config$on_select_col)
+}
+
 get_cluster_grouping <- function(config, group) {
   vapply(
     X = config$nodes$id,
@@ -372,6 +390,7 @@ legend_nodes <- function(font_size = 20) {
       "Imported",
       "Missing",
       "Object",
+      "Dynamic",
       "Function",
       "File",
       "Cluster"
@@ -383,10 +402,11 @@ legend_nodes <- function(font_size = 20) {
       "failed",
       "import",
       "missing",
-      rep("generic", 4)
+      rep("generic", 5)
     )),
     shape = node_shape(c(
       rep("object", 7),
+      "dynamic",
       "funct",
       "file",
       "cluster"
@@ -414,6 +434,11 @@ cluster_nodes <- function(config) {
       config = list(nodes = new_node, font_size = config$font_size))
     new_node$label <- new_node$id <-
       paste0(config$group, ": ", cluster)
+
+    if (!is.null(config$on_select_col)) {
+      new_node$on_select_col <- config$nodes[index, "on_select_col"][[1]]
+    }
+
     matching <- config$nodes$id[index]
     new_node$title <- paste(matching, collapse = ", ")
     new_node$title <- crop_text(new_node$title, width = hover_width)
@@ -468,6 +493,7 @@ categorize_nodes <- function(config) {
     nodes[running, "status"] <- "running"
     nodes[failed, "status"] <- "failed"
     nodes$type <- "object"
+    nodes[dynamic, "type"] <- "dynamic"
     nodes[is_encoded_path(nodes$id), "type"] <- "file"
     nodes[functions, "type"] <- "function"
     nodes
@@ -503,6 +529,7 @@ style_nodes <- function(config) {
     nodes[nodes$status == "outdated", "color"] <- node_color("outdated")
     nodes[nodes$status == "up to date", "color"] <- node_color("up_to_date")
     nodes[nodes$type == "object", "shape"] <- node_shape("object")
+    nodes[nodes$type == "dynamic", "shape"] <- node_shape("dynamic")
     nodes[nodes$type == "file", "shape"] <- node_shape("file")
     nodes[nodes$type == "function", "shape"] <- node_shape("funct")
     nodes[nodes$type == "cluster", "shape"] <- node_shape("cluster")
@@ -531,6 +558,7 @@ node_shape <- Vectorize(function(x) {
   switch(
     x,
     object = "dot",
+    dynamic = "star",
     file = "square",
     funct = "triangle",
     cluster = "diamond",
