@@ -1,15 +1,39 @@
 drake_meta_ <- function(target, config) {
+  class <- ifelse(is_subtarget(target, config), "subtarget", "target")
+  class(target) <- class
+  drake_meta_impl(target, config)
+}
+
+drake_meta_impl <- function(target, config) {
+  UseMethod("drake_meta_impl")
+}
+
+drake_meta_impl.subtarget <- function(target, config) {
+  seed <- config$layout[[target]]$seed %||NA%
+    seed_from_basic_types(config$seed, target)
+  list(
+    name = target,
+    target = target,
+    imported = FALSE,
+    isfile = FALSE,
+    time_start = proc.time(),
+    seed = as.integer(seed)
+  )
+}
+
+drake_meta_impl.default <- function(target, config) {
   layout <- config$layout[[target]]
   meta <- list(
     name = target,
     target = target,
     imported = layout$imported %||% TRUE,
-    missing = !config$cache$exists(key = target),
+    missing = target_missing(target, config),
     seed = as.integer(
       layout$seed %||NA% seed_from_basic_types(config$seed, target)
     ),
     time_start = proc.time(),
-    file_out = layout$deps_build$file_out
+    file_out = layout$deps_build$file_out,
+    dynamic = is.call(layout$dynamic)
   )
   if (meta$imported) {
     meta$isfile <- is_encoded_path(target)
@@ -36,28 +60,47 @@ drake_meta_ <- function(target, config) {
   }
   if (!is.null(meta$trigger$change)) {
     try_load(layout$deps_change$memory, config = config)
-    meta$trigger$value <- eval(meta$trigger$change, config$eval)
+    meta$trigger$value <- eval(meta$trigger$change, config$envir_targets)
+  }
+  if (is_dynamic(target, config)) {
+    meta$dynamic_dependency_hash <- dynamic_dependency_hash(target, config)
+    meta$max_expand <- config$max_expand
   }
   meta
 }
 
+target_missing <- function(target, config) {
+  !target_exists(target, config)
+}
+
+target_exists <- function(target, config) {
+  config$cache$exists(key = target) &
+    config$cache$exists(key = target, namespace = "meta")
+}
+
 # A numeric hash that could be used as a
 # random number generator seed. Generated
 # from arguments of basic types such as
 # numerics and characters.
 seed_from_basic_types <- function(...) {
   x <- paste0(..., collapse = "")
+  integer_hash(x = x, mod = .Machine$integer.max)
+}
+
+integer_hash <- function(x, mod = .Machine$integer.max) {
   hash <- digest::digest(x, algo = "murmur32", serialize = FALSE)
   hexval <- paste0("0x", hash)
-  utils::type.convert(hexval) %% .Machine$integer.max
+  as.integer(utils::type.convert(hexval) %% mod)
 }
 
 dependency_hash <- function(target, config) {
-  x <- config$layout[[target]]$deps_build
+  layout <- config$layout[[target]]
+  x <- layout$deps_build
   deps <- c(x$globals, x$namespaced, x$loadd, x$readd)
   if (is_imported(target, config)) {
     deps <- c(deps, x$file_in, x$knitr_in)
   }
+  deps <- setdiff(deps, layout$deps_dynamic)
   if (!length(deps)) {
     return("")
   }
@@ -65,6 +108,18 @@ dependency_hash <- function(target, config) {
   deps <- as.character(deps)
   deps <- unique(deps)
   deps <- sort(deps)
+  dependency_hash_impl(deps, config)
+}
+
+dynamic_dependency_hash <- function(target, config) {
+  layout <- config$layout[[target]]
+  deps_dynamic <- layout$deps_dynamic
+  deps_trace <- sort(unique(layout$deps_dynamic_trace))
+  deps <- c(deps_dynamic, deps_trace)
+  dependency_hash_impl(deps, config)
+}
+
+dependency_hash_impl <- function(deps, config) {
   out <- config$cache$memo_hash(
     x = deps,
     fun = self_hash,
@@ -154,9 +209,7 @@ storage_hash <- function(
   if (!file.exists(file)) {
     return(NA_character_)
   }
-  not_cached <- !config$cache$exists(key = target) ||
-    !config$cache$exists(key = target, namespace = "meta")
-  if (not_cached) {
+  if (target_missing(target, config)) {
     return(rehash_storage(target = target, file = file, config = config))
   }
   meta <- config$cache$get(key = target, namespace = "meta")
