@@ -1,5 +1,6 @@
-#' @title Expose all the imports in a package so `make()` can detect
-#'   all the package's nested functions.
+#' @title Expose all the objects in a package so `make()` can detect
+#'   them as imported dependencies.
+#' \lifecycle{stable}
 #' @description When `drake` analyzes the functions in your environment,
 #'   it understands that some of your functions
 #'   are nested inside other functions.
@@ -22,17 +23,17 @@
 #' @export
 #' @return The environment that the exposed imports are loaded into.
 #'   Defaults to your R workspace.
-#' @param package name of the package, either a symbol or a string,
+#' @param package Name of the package, either a symbol or a string,
 #'   depending on `character_only`.
-#' @param character_only logical, whether to interpret `package`
+#' @param character_only Logical, whether to interpret `package`
 #'   as a character string or a symbol (quoted vs unquoted).
-#' @param envir environment to load the exposed package imports.
+#' @param envir Environment to load the exposed package imports.
 #'   You will later pass this `envir` to [make()].
-#' @param jobs number of parallel jobs for the parallel processing
+#' @param jobs Number of parallel jobs for the parallel processing
 #'   of the imports.
 #' @examples
 #' \dontrun{
-#' test_with_dir("contain this example's side effects", {
+#' isolate_example("contain side effects", {
 #' # Suppose you have a workflow that uses the `digest()` function,
 #' # which computes the hash of an object.
 #'
@@ -44,9 +45,10 @@
 #'   g(x)
 #' }
 #' plan <- drake_plan(x = f(1))
+#' cache <- storr::storr_environment() # optional
 #'
 #' # Here are the reproducibly tracked objects in the workflow.
-#' config <- drake_config(plan)
+#' config <- drake_config(plan, cache = cache, history = FALSE)
 #' tracked(config)
 #'
 #' # But the digest() function has dependencies too.
@@ -58,7 +60,7 @@
 #' # a package's inner functions.
 #'
 #' expose_imports(digest)
-#' config <- drake_config(plan)
+#' config <- drake_config(plan, cache = cache, history = FALSE)
 #' new_objects <- tracked(config)
 #' head(new_objects, 10)
 #' length(new_objects)
@@ -66,8 +68,7 @@
 #' # Now when you call `make()`, `drake` will dive into `digest`
 #' # to import dependencies.
 #'
-#' cache <- storr::storr_environment() # just for examples
-#' make(plan, cache = cache)
+#' make(plan, cache = cache, history = FALSE)
 #' head(cached(cache = cache), 10)
 #' length(cached(cache = cache))
 #'
@@ -83,7 +84,7 @@
 #' g <- function(x) {
 #'   digest::digest(x) # Was previously just digest()
 #' }
-#' config <- drake_config(plan)
+#' config <- drake_config(plan, cache = cache, history = FALSE)
 #' tracked(config)
 #' })
 #' }
@@ -100,17 +101,22 @@ expose_imports <- function(
   expose_envir(from = getNamespace(package), to = envir, jobs = jobs)
 }
 
-expose_envir <- function(from, to, jobs, keep = ls(from, all.names = TRUE)) {
+expose_envir <- function(from, to, jobs, keep = names(from)) {
   from <- as.list(from, all.names = TRUE)[keep]
   from <- list2env(from, parent = globalenv())
   lightly_parallelize(
     X = ls(from, all.names = TRUE),
     FUN = function(name) {
-      assign(
-        x = name,
-        envir = to,
-        value = `environment<-`(get(name, envir = from), from)
-      )
+      value <- get(name, envir = from)
+      if (typeof(value) == "closure") {
+        assign(
+          x = name,
+          envir = to,
+          value = `environment<-`(value, from)
+        )
+      } else {
+        assign(x = name, envir = to, value = value)
+      }
     },
     jobs = jobs
   )
