@@ -1,9 +1,159 @@
+#' @title Transformations in `drake_plan()`. \lifecycle{maturing}
+#' @name transformations
+#' @aliases map split cross combine group
+#' @description In [drake_plan()], you can define whole batches
+#'   of targets with transformations such as
+#'   `map()`, `split()`, `cross()`, and `combine()`.
+#' @details For details, see
+#'   <https://books.ropensci.org/drake/plans.html#large-plans>.
+#' @section Transformations:
+#'  `drake` has special syntax for generating large plans.
+#'  Your code will look something like
+#'  `drake_plan(y = target(f(x), transform = map(x = c(1, 2, 3)))`
+#'  You can read about this interface at
+#'  <https://books.ropensci.org/drake/plans.html#large-plans>. # nolint
+#' @section Static branching:
+#'   In static branching, you define batches of targets
+#'   based on information you know in advance.
+#'   Overall usage looks like
+#'   `drake_plan(<x> = target(<...>, transform = <call>)`,
+#'   where
+#'   - `<x>` is the name of the target or group of targets.
+#'   - `<...>` is optional arguments to [target()].
+#'   - `<call>` is a call to one of the transformation functions.
+#'
+#'   Transformation function usage:
+#'   - `map(..., .data, .id, .tag_in, .tag_out)`
+#'   - `split(..., slices, margin = 1L, drop = FALSE, .tag_in, .tag_out)`
+#'   - `cross(..., .data, .id, .tag_in, .tag_out)`
+#'   - `combine(..., .by, .id, .tag_in, .tag_out)`
+#' @section Dynamic branching:
+#'   Dynamic branching is not yet implemented,
+#'   but this is what it usage will look like.
+#'   - `map(..., .trace)`
+#'   - `cross(..., .trace)`
+#'   - `group(..., .by, .trace)`
+#'
+#'  `map()` and `cross()` create dynamic sub-targets from the variables
+#'  supplied to the dots. As with static branching, the variables
+#'  supplied to `map()` must all have equal length.
+#'   `group(f(data), .by = x)` makes new dynamic
+#'   sub-targets from `data`. Here, `data` can be either static or dynamic.
+#'   If `data` is dynamic, `group()` aggregates existing sub-targets.
+#'   If `data` is static, `group()` splits `data` into multiple
+#'   subsets based on the groupings from `.by`.
+#'
+#'  Differences from static branching:
+#'  - `...` must contain *unnamed* symbols with no values supplied,
+#'    and they must be the names of targets.
+#'  - Arguments `.id`, `.tag_in`, and `.tag_out` no longer apply.
+#'
+#' @param ... Grouping variables. New grouping variables must be
+#'   supplied with their names and values, existing grouping variables
+#'   can be given as symbols without any values assigned.
+#'   For dynamic branching, the entries in `...` must be unnamed symbols
+#'   with no values supplied, and they must be the names of targets.
+#' @param .data A data frame of new grouping variables with
+#'   grouping variable names as column names and values as elements.
+#' @param .id Symbol or vector of symbols naming grouping variables
+#'   to incorporate into target names. Useful for creating short target
+#'   names. Set `.id = FALSE` to use integer indices as target name suffixes.
+#' @param .tag_in A symbol or vector of symbols. Tags assign targets
+#'   to grouping variables. Use `.tag_in` to assign *untransformed*
+#'   targets to grouping variables.
+#' @param .tag_out Just like `.tag_in`, except that `.tag_out`
+#'   assigns *transformed* targets to grouping variables.
+#' @param slice Number of slices into which `split()` partitions the data.
+#' @param margin Which margin to take the slices in `split()`. Same meaning
+#'   as the `MARGIN` argument of `apply()`.
+#' @param drop Logical, whether to drop a dimension if its length is 1.
+#'   Same meaning as `mtcars[, 1L, drop = TRUE]` versus
+#'   `mtcars[, 1L, drop = TRUE]`.
+#' @param .by Symbol or vector of symbols of grouping variables.
+#'   `combine()` aggregates/groups targets by the grouping variables in `.by`.
+#'   For dynamic branching, `.by` can only take one variable at a time,
+#'   and that variable must be a vector. Ideally, it should take
+#'   little space in memory.
+#' @param .trace Symbol or vector of symbols for the dynamic trace.
+#'   The dynamic trace allows you to keep track of the values of
+#'   dynamic dependencies are associated with individual sub-targets.
+#'   For `combine()`, `.trace` must either be empty or the same as the
+#'   variable given for `.by`.
+#'   See [get_trace()] and [read_trace()] for examples and other details.
+#' @examples
+#' # Static branching
+#' models <- c("glm", "hierarchical")
+#' plan <- drake_plan(
+#'   data = target(
+#'     get_data(x),
+#'     transform = map(x = c("simulated", "survey"))
+#'   ),
+#'   analysis = target(
+#'     analyze_data(data, model),
+#'     transform = cross(data, model = !!models, .id = c(x, model))
+#'   ),
+#'   summary = target(
+#'     summarize_analysis(analysis),
+#'     transform = map(analysis, .id = c(x, model))
+#'   ),
+#'   results = target(
+#'     bind_rows(summary),
+#'     transform = combine(summary, .by = data)
+#'   )
+#' )
+#' plan
+#' if (requireNamespace("styler")) {
+#'   print(drake_plan_source(plan))
+#' }
+#' # Static splitting
+#' plan <- drake_plan(
+#'   analysis = target(
+#'     analyze(data),
+#'     transform = split(data, slices = 3L, margin = 1L, drop = FALSE)
+#'   )
+#' )
+#' print(plan)
+#' if (requireNamespace("styler", quietly = TRUE)) {
+#'   print(drake_plan_source(plan))
+#' }
+#' # Static tags:
+#' drake_plan(
+#'   x = target(
+#'     command,
+#'     transform = map(y = c(1, 2), .tag_in = from, .tag_out = c(to, out))
+#'   ),
+#'   trace = TRUE
+#' )
+#' plan <- drake_plan(
+#'   survey = target(
+#'     survey_data(x),
+#'     transform = map(x = c(1, 2), .tag_in = source, .tag_out = dataset)
+#'   ),
+#'   download = target(
+#'     download_data(),
+#'     transform = map(y = c(5, 6), .tag_in = source, .tag_out = dataset)
+#'   ),
+#'   analysis = target(
+#'     analyze(dataset),
+#'     transform = map(dataset)
+#'   ),
+#'   results = target(
+#'     bind_rows(analysis),
+#'     transform = combine(analysis, .by = source)
+#'   )
+#' )
+#' plan
+#' if (requireNamespace("styler", quietly = TRUE)) {
+#'   print(drake_plan_source(plan))
+#' }
+NULL
+
 #' @title Transform a plan
 #' \lifecycle{maturing}
 #' @description Evaluate the `map()`, `cross()`, `split()` and
 #'   `combine()` operations in the `transform` column of a
 #'   `drake` plan.
-#' @details <https://ropenscilabs.github.io/drake-manual/plans.html#large-plans> # nolint
+#' @details <https://books.ropensci.org/drake/plans.html#large-plans> # nolint
 #' @export
 #' @seealso drake_plan, map, split, cross, combine
 #' @param plan A `drake` plan with a `transform` column
@@ -11,14 +161,15 @@
 #' @param trace Logical, whether to add columns to show
 #'   what happens during target transformations.
 #' @param max_expand Positive integer, optional.
-#'   Maximum number of targets to generate in each
+#'   `max_expand` is the maximum number of targets to generate in each
 #'   `map()`, `split()`, or `cross()` transform.
-#'   If massive number of targets, consider setting `max_expand`
-#'   to a small number. That way, you can test and visualize
-#'   your workflow before scaling up to production.
-#'   Note: `max_expand` is not for production workflows.
-#'   When it comes time to generate the end product,
-#'   either unset `max_expand` or manually set it to `NULL`.
+#'   Useful if you have a massive plan and you want to
+#'   test and visualize a strategic subset of targets
+#'   before scaling up.
+#'   Note: the `max_expand` argument of `drake_plan()` and
+#'   `transform_plan()` is for static branching only.
+#'   The dynamic branching `max_expand`
+#'   is an argument of `make()` and `drake_config()`.
 #' @param tidy_eval Logical, whether to use tidy evaluation
 #'   (e.g. unquoting/`!!`) when resolving commands.
 #'   Tidy evaluation in transformations is always turned on
@@ -134,16 +285,31 @@ transform_plan_ <- function(
     plan <- sub_in_plan(plan, rows, index)
     old_cols(plan) <- old_cols
   }
+  plan <- dsl_trace(plan = plan, trace = trace)
+  old_cols(plan) <- plan$transform <- NULL
+  plan <- dsl_tidy_eval(plan = plan, tidy_eval = tidy_eval, envir = envir)
+  plan <- dsl_sanitize(plan = plan, sanitize = sanitize, envir = envir)
+  plan
+}
+
+dsl_trace <- function(plan, trace) {
   if (!trace) {
     keep <- as.character(intersect(colnames(plan), old_cols(plan)))
     plan <- plan[, intersect(colnames(plan), old_cols(plan)), drop = FALSE]
   }
-  old_cols(plan) <- plan$transform <- NULL
+  plan
+}
+
+dsl_tidy_eval <- function(plan, tidy_eval, envir) {
   if (tidy_eval) {
     for (col in setdiff(colnames(plan), c("target", "transform"))) {
       plan[[col]] <- tidyeval_exprs(plan[[col]], envir = envir)
     }
   }
+  plan
+}
+
+dsl_sanitize <- function(plan, sanitize, envir) {
   if (sanitize) {
     plan <- sanitize_plan(plan, envir = envir)
   }
