@@ -1,5 +1,9 @@
 drake_context("callr")
 
+test_with_dir("r_make_message", {
+  expect_message(r_make_message(force = TRUE))
+})
+
 test_with_dir("config file missing", {
   skip_on_cran()
   skip_if_not_installed("callr")
@@ -35,8 +39,12 @@ test_with_dir("basic functions with default _drake.R file", {
     is.data.frame(r_drake_build(small, r_args = list(show = FALSE)))
   )
   skip_if_not_installed("visNetwork")
-  info <- r_drake_graph_info(r_args = list(show = FALSE))
+  info <- r_drake_graph_info(
+    r_args = list(show = FALSE),
+    build_times = "none"
+  )
   expect_true(all(c("nodes", "edges") %in% names(info)))
+  skip_if_not_installed("lubridate")
   out <- r_predict_workers(r_args = list(show = FALSE))
   expect_equal(sort(colnames(out)), c("target", "worker"))
   skip_if_not_installed("lubridate")
@@ -190,7 +198,25 @@ test_with_dir("callr RStudio addins", {
   expect_true(length(rs_addin_r_outdated(r_args, .print = FALSE)) > 1)
   rs_addin_r_make(r_args)
   expect_equal(rs_addin_r_outdated(r_args, .print = FALSE), character(0))
+  skip_if_not_installed("lubridate")
   skip_if_not_installed("visNetwork")
   graph <- rs_addin_r_vis_drake_graph(r_args, .print = FALSE)
   expect_true(inherits(graph, "visNetwork"))
 })
+
+test_with_dir("errors keep their informative messages (#969)", {
+  skip_if_not_installed("callr")
+  code <- c(
+    "library(drake)",
+    "my_plan <- drake_plan(",
+    "  x = stop('7a3f077af6c8e425')",
+    ")",
+    "drake_config(my_plan)"
+  )
+  writeLines(code, "_drake.R")
+  expect_error(
+    r_make(r_args = list(show = FALSE)),
+    regexp = "7a3f077af6c8e425",
+    class = "callr_error"
+  )
+})
